==> xpilot_4.0.0.orig.tar.gz: xpilot-4.0.0/src/mapedit/default_colors.h <==
/*
 * XMapEdit, the XPilot Map Editor.  Copyright (C) 1993 by
 *
 *      Aaron Averill           <averila@oes.orst.edu>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * Modifications to XMapEdit
 * 1996:
 *      Robert Templeman        <mbcaprt@mphhpd.ph.man.ac.uk>
 * 1997:
 *      William Docter          <wad2@lehigh.edu>
 *
 * $Id: default_colors.h,v 1.2 1998/04/22 15:43:59 bert Exp $
 */

#define COLOR_BACKGROUND "black"
#define COLOR_FOREGROUND  "gray85"
#define COLOR_HIGHLIGHT  "white"
#define COLOR_SHADOW     "gray80"

#define COLOR_WALL      "cyan"
#define COLOR_DECOR     "orange"
#define COLOR_FUEL      "red"
#define COLOR_TREASURE  "pink"
#define COLOR_TARGET    "pink"
#define COLOR_ITEM_CONC "pink"

#define COLOR_GRAVITY   "green"
#define COLOR_CURRENT   "green"
#define COLOR_WORMHOLE  "green"

#define COLOR_BASE      "white"
#define COLOR_CANNON    "purple"

==> xpilot_4.5.3.orig.tar.gz: xpilot-4.5.3/src/mapedit/default_colors.h <==
/*
 * XMapEdit, the XPilot Map Editor.  Copyright (C) 1993 by
 *
 *      Aaron Averill           <averila@oes.orst.edu>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * Modifications to XMapEdit
 * 1996:
 *      Robert Templeman        <mbcaprt@mphhpd.ph.man.ac.uk>
 * 1997:
 *      William Docter          <wad2@lehigh.edu>
 *
 * $Id: default_colors.h,v 5.1 2001/05/19 23:08:37 millerjl Exp $
 */
#define COLOR_BACKGROUND "black"
#define COLOR_FOREGROUND  "gray"
#define COLOR_HIGHLIGHT  "white"
#define COLOR_SHADOW     "black"

#define COLOR_WALL      "blue"
#define COLOR_DECOR     "green"
#define COLOR_FUEL      "red"
#define COLOR_TREASURE  "red"
#define COLOR_TARGET    "red"
#define COLOR_ITEM_CONC "red"

#define COLOR_GRAVITY   "red"
#define COLOR_CURRENT   "red"
#define COLOR_WORMHOLE  "red"

#define COLOR_BASE      "white"
#define COLOR_CANNON    "white"
#define COLOR_FRICTION  "magenta"
